@@ -1,5 +1,8 @@
 from dataclasses import dataclass
 from collections import Counter
+from zjwbox.boxtools.alert_exit import alertExit
+from datetime import datetime
+
 
 @dataclass
 class Infer(object):
@@ -42,7 +45,10 @@ class Infer(object):
             print(None)
                 
 
-                
+alertExit()
+
+
 # if __name__ == "__main__":
 #     p = Infer("set")
-#     print( p[1, 5,  ...,100] )
\ No newline at end of file
+#     print( p[1, 5,  ...,100] )
+
